archon
====================

|build_status|_ |code_coverage|_

A python framework based on Flask+SQLAlchemy used for developing realtime websocket APIs.
Currently supports CRUD and pubsub.


.. |build_status| image:: https://travis-ci.org/JasperStam/archon.svg?branch=master
.. _build_status: https://travis-ci.org/JasperStam/archon
.. |code_coverage| image:: https://codecov.io/gh/JasperStam/archon/branch/master/graph/badge.svg
.. _code_coverage: https://codecov.io/gh/JasperStam/archon
